@@ -1,11 +1,9 @@
 #' Fitting height-diameter models
 #'
-#' This function fits and compares (optional) height-diameter models.
+#' @description This function fits and compares (optional) height-diameter models.
 #'
-#' @param D Vector with diameter measurements (in cm). NA values are accepted but a
-#' minimum of 10 valid entries (i.e. having a corresponding height in H) is required.
-#' @param H Vector with total height measurements (in m). NA values are accepted but a minimum of 10 valid entries
-#' (i.e. having a corresponding diameter in D) is required.
+#' @param D Vector with diameter measurements (in cm). NA values are accepted but a minimum of 10 valid entries (i.e. having a corresponding height in H) is required.
+#' @param H Vector with total height measurements (in m). NA values are accepted but a minimum of 10 valid entries (i.e. having a corresponding diameter in D) is required.
 #' @param method Method used to fit the relationship.
 #' To be chosen between:
 #'   - log1, log2
@@ -26,9 +24,10 @@
 #'
 #'
 #' @return
-#' If plot is NULL or has a single value, a single list is returned. If there is more than one plot,
+#' If `plot` is NULL or has a single value, a single list is returned. If there is more than one plot,
 #' multiple embedded lists are returned with plots as the list names.
-#' Returns a list if the parameter model is not null:
+#' 
+#' If `model` is not null (model comparison), returns a list :
 #'   - `input`: list of the data used to construct the model (list(H, D))
 #'   - `model`: outputs of the model (same outputs as given by [stats::lm()], [stats::nls()])
 #'   - `RSE`: Residual Standard Error of the model
@@ -39,19 +38,19 @@
 #'   - `formula`: Formula of the model
 #'   - `method`: Name of the method used to construct the model
 #'   - `predicted`: Predicted height values
+#'   - `fitPlot`: a ggplot object containing the model fitting plot
 #'
 #'
-#' If the parameter model is null, the function return a graph with all the methods for
+#' If the parameter model is null, the function return a plot with all the methods for
 #' comparison, the function also returns a data.frame with:
-#'   - `method`: The method that had been used to construct the graph
-#'   - `color`: The color of the curve in the graph
+#'   - `method`: The method that had been used to construct the plot
 #'   - `RSE`: Residual Standard Error of the model
 #'   - `RSElog`: Residual Standard Error of the log model (`NULL` if other model)
 #'   - `Average_bias`: The average bias for the model
 #'
 #'
 #'
-#' @author Maxime REJOU-MECHAIN, Arthur PERE, Ariane TANGUY
+#' @author Maxime REJOU-MECHAIN, Arthur PERE, Ariane TANGUY, Arthur Bailly
 #' @seealso [retrieveH()]
 #'
 #' @export
@@ -61,94 +60,91 @@
 #' # Load a data set
 #' data(NouraguesHD)
 #'
-#' # To model the height from a dataset
+#' # Fit H-D models for the Nouragues dataset
 #' \donttest{
 #' HDmodel <- modelHD(D = NouraguesHD$D, H = NouraguesHD$H, drawGraph = TRUE)
 #' }
 #'
-#' # If the method needed is known
-#' HDmodel <- modelHD(D = NouraguesHD$D, H = NouraguesHD$H, method = "weibull", drawGraph = TRUE)
-#' HDmodel <- modelHD(D = NouraguesHD$D, H = NouraguesHD$H, method = "log1", drawGraph = TRUE)
+#' # For a chosen model
+#' HDmodel <- modelHD(D = NouraguesHD$D, H = NouraguesHD$H,
+#' method = "log2", drawGraph = TRUE)
 #'
 #' # Using weights
 #' HDmodel <- modelHD(
-#'   D = NouraguesHD$D, H = NouraguesHD$H, method = "weibull", useWeight = TRUE,
-#'   drawGraph = TRUE
-#' )
+#'   D = NouraguesHD$D, H = NouraguesHD$H,
+#'   method = "log2", useWeight = TRUE,
+#'   drawGraph = TRUE)
+#' 
+#' # With multiple stands (plots)
+#' HDmodel <- modelHD(
+#'   D = NouraguesHD$D, H = NouraguesHD$H,
+#'   method = "log2", useWeight = TRUE, 
+#'   plot = NouraguesHD$plotId, drawGraph = TRUE)
+#' 
 #' @importFrom graphics legend lines par plot grid axis
 #' @importFrom stats SSmicmen lm median na.omit quantile rnorm sd predict coef
 #' @importFrom utils data
 #' @importFrom data.table data.table
+#' @importFrom ggplot2 ggplot aes geom_point geom_smooth labs theme_minimal theme scale_x_continuous scale_y_continuous element_text 
 
 modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, plot = NULL) {
 
-  # # To maintain user's original options
-  oldpar <- par(no.readonly = TRUE)
-  on.exit(par(oldpar))
-  
-  # parameters verification -------------------------------------------------
+  # Checking arguments -------------------------------------------------
 
   # Check if there is enough data to compute an accurate model
   nbNonNA <- sum(!is.na(H))
   if (nbNonNA < 15) {
     stop("The data has not enough height data (less than 15 non NA)")
   }
-
   if (length(H) != length(D)) {
     stop("Your vector D and H do not have the same length")
   }
-
   if (!is.null(method)) {
     method <- tolower(method)
   }
-
   methods <- c("log1", "log2", "weibull", "michaelis")
   if (!is.null(method) && !(method %in% methods)) {
     stop("Chose your method among those ones : ", paste(methods, collapse = ", "))
   }
-
   if (!is.logical(useWeight)) {
     stop("UseWeight argument must be a boolean")
   }
-
   if (!is.logical(drawGraph)) {
     stop("drawGraph argument must be a boolean")
   }
-
   if (!is.null(plot) && !length(plot) %in% c(1, length(D))) {
     stop("The length of the 'plot' vector must be either 1 or the length of D")
   }
-
-
-  if (!is.null(plot)) {
-    drawGraph <- FALSE
-  }
-
-
-
-  # If there is a plot ID ---------------------------------------------------
-
+  # if (!is.null(plot)) { 
+  #   drawGraph <- FALSE
+  # }
+  
+  
+  # Multiple plots managment ---------------------------------------------------
+  
   # if there is multiple plots in the plot vector
   if (!is.null(plot) && length(unique(plot)) != 1) {
     Hdata <- data.table(H = H, D = D, plot = plot)
-
+    
     output <- lapply(split(Hdata, by = "plot", keep.by = TRUE), function(subData) {
       suppressMessages(modelHD(
         subData$D, subData$H, method, useWeight,
         drawGraph, unique(subData$plot)
       ))
     })
-
+    
     if (is.null(method)) {
       message("To build a HD model you must use the parameter 'method' in this function")
     }
-
+    
     return(output)
   }
+  
+
 
   # functions ----------------------------------------------------------------
 
-  # fonction to choose the fonction
+  # function to select the method
   modSelect <- function(Hdata, method, useGraph = FALSE) {
     output <- list()
 
@@ -158,7 +154,6 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
       mod <- loglogFunction(Hdata, method)
       output$RSElog <- summary(mod)$sigma
 
-
       # Baskerville correction 1972
       output$Hpredict <- exp(predict(mod) + 0.5 * output$RSElog^2)
 
@@ -189,65 +184,45 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
     output$residuals <- res
     output$mod <- mod
 
-
     return(output)
   }
 
 
-
   # function to draw the beining of the graph
   drawPlotBegin <- function(givenMethod = FALSE, plotId) {
     main_title <- ifelse(givenMethod == FALSE, "Model comparison", paste("Selected model : ", givenMethod))
-
-    par(mar = c(5, 5, 3, 3))
-    plot(Hdata$D, Hdata$H,
-      pch = 20, cex = 0.5, col = "grey50", log = "xy", las = 1,
-      xlab = "D (cm)", ylab = "H (m)", cex.lab = 1.8, cex.axis = 1.5,
-      main = main_title,
-      cex.main = 2, axes = FALSE, frame.plot = FALSE
-    )
-    grid(col = "grey80", lty = 1, equilogs = FALSE)
-    axis(side = 1, lty = "blank", las = 1)
-    axis(side = 2, lty = "blank", las = 1)
+    
+    starting_plot <- ggplot(data = Hdata, mapping = aes(x=D, y=H)) + 
+      geom_point(col="grey50") + 
+      labs(title = main_title, x="D (cm)", y="H (m)") + 
+      #coord_trans(x = "log", y = "log") + theme_minimal()
+      scale_x_continuous(transform = "log10", n.breaks = 8, )+ scale_y_continuous(transform = "log10", n.breaks = 8) + 
+      theme_minimal() + theme(plot.title = element_text(hjust = 0.5))
+    return(starting_plot)
   }
 
 
   # Data processing ---------------------------------------------------------
-
   Hdata <- data.table(H = H, D = D)
   Hdata <- na.omit(Hdata) # Remove NA values
   weight <- NULL
 
   # Vector of diameter used only for visualisation purpose
-  D_Plot <- data.frame(D = Hdata[, seq(floor(min(D)), ceiling(max(D)), 0.5)])
-
+  #D_Plot <- data.frame(D = Hdata[, seq(floor(min(D)), ceiling(max(D)), 0.5)])
+  D_Plot <- data.frame(D = Hdata[, 10^seq(log10(floor(min(D))), log10(ceiling(max(D))), l=100 )])
+  
   # If the measures need to be weighted
   if (useWeight == TRUE) {
     weight <- Hdata[, D^2 * H]
   } # weight is proportional to tree volume
 
 
-
-  # If we gave the function a method ----------------------------------------
-
+  # If one method is supplied  ----------------------------------------------
   if (!is.null(method)) {
     output <- modSelect(Hdata, method, drawGraph)
 
-    ####### if drawGraph is true
-    if (drawGraph) {
-      drawPlotBegin(method, plot)
-
-      lines(D_Plot$D, output$Hpredict_plot, lwd = 2, col = "blue")
-      legend("bottomright", c("Data", "Model selected"),
-        lty = c(3, 1), lwd = c(3, 3),
-        col = c("grey", "blue"), cex = 1.5
-      )
-    }
-
     ################## Return the model chosen
 
-    # Results (RSE, model coefficient, residuals, R?)
-
     out <- list(
       input = list(H = Hdata$H, D = Hdata$D),
       model = output$mod,
@@ -264,45 +239,56 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
       out$RSElog <- output$RSElog
     }
 
+    ####### if drawGraph is true
+    if (drawGraph) {
+      fitPlot <- drawPlotBegin(method, plot) + 
+        geom_smooth(
+          data = data.frame(x = D_Plot$D, y = output$Hpredict_plot), mapping = aes(x,y),
+          formula = y~x, method = "loess"
+          )
+      print(fitPlot)
+      out$fitPlot <- fitPlot
+    }
+
     return(out)
-  } else {
+  } else { # If no method was supplied
 
     # Compare Models ----------------------------------------------------------
-    if (is.null(plot)) {
-      drawPlotBegin(plotId = plot)
-    }
-    color <- c("blue", "green", "orange", "purple")
 
-    result <- rbindlist(lapply(1:length(methods), function(i) {
+    output_list <- list()
+    df_plot_list <- list()
+    for(i in 1:length(methods)) {
       method <- methods[i]
 
-      out <- modSelect(Hdata, method, useGraph = is.null(plot))
+      out <- modSelect(Hdata, method, useGraph = drawGraph)
 
-      output <- list(
-        method = method, color = color[i],
+      output_list[[i]] <- list(
+        method = method,
         RSE = out$RSE, # Residual standard error
         RSElog = out$RSElog,
         Average_bias = out$Average_bias
       )
 
-      if (is.null(plot)) {
-        lines(D_Plot$D, out$Hpredict_plot, lwd = 2, col = color[i], lty = i)
-      }
-      if (!is.null(plot)) {
-        output[["color"]] <- NULL
+      if (drawGraph) {
+        df_plot_list[[i]] <- data.frame(x = D_Plot$D, y = out$Hpredict_plot, method=methods[i])
       }
+    }
+    result <- rbindlist(output_list,fill=T)
 
-      return(output)
-    }), fill = TRUE)
-
-    if (is.null(plot)) {
-      legend("bottomright", methods,
-        lty = 1:5, lwd = 2, cex = 1,
-        col = color
-      )
+    if (drawGraph) {
+      fitPlot <- drawPlotBegin(plotId = plot)
+      df_plot <- rbindlist(df_plot_list)
+      fitPlot <- fitPlot +  
+        geom_smooth(
+          data = df_plot, mapping = aes(x,y,colour = method,linetype = method),
+          formula = y~x, method = "loess") +
+        theme(legend.position = "bottom")
+      print(fitPlot)
     }
 
     message("To build a HD model you must use the parameter 'method' in this function")
+    
+    
     return(data.frame(result))
   }
 }
